==> subparse-0.5.1.tar.gz: subparse-0.5.1/setup.py <==
import os
import sys

from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

py_version = sys.version_info[:2]
PY3 = py_version[0] == 3

here = os.path.abspath(os.path.dirname(__file__))

def _read(path):
    with open(path, 'r') as fp:
        return fp.read()

try:
    README = _read(os.path.join(here, 'README.rst'))
    CHANGES = _read(os.path.join(here, 'CHANGES.rst'))
except:
    README = CHANGES = ''

install_requires = [
]

tests_require = install_requires + [
    'pytest',
]

class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = ['--pyargs', self.test_suite]
    def run_tests(self):
        #  import here, cause outside the eggs aren't loaded
        import pytest
        result = pytest.main(self.test_args)
        sys.exit(result)

setup(
    name='subparse',
    version='0.5.1',
    description='A command line helper library for extensible subcommands',
    long_description=README + '\n\n' + CHANGES,
    url='https://github.com/mmerickel/subparse',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords='argparse cli commandline subcommand',
    author='Michael Merickel',
    author_email='oss@m.merickel.org',
    license='MIT',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=True,
    install_requires=install_requires,
    tests_require=tests_require,
    test_suite='subparse.tests',
    cmdclass={'test': PyTest},
)

==> subparse-0.5.2.tar.gz: subparse-0.5.2/setup.py <==
from setuptools import setup, find_packages


def readfile(name):
    with open(name) as f:
        return f.read()


readme = readfile('README.rst')
changes = readfile('CHANGES.rst')

tests_require = ['pytest', 'pytest-cov']

setup(
    name='subparse',
    version='0.5.2',
    description='A command line helper library for extensible subcommands',
    long_description=readme + '\n\n' + changes,
    url='https://github.com/mmerickel/subparse',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords=['argparse', 'cli', 'commandline', 'subcommand'],
    author='Michael Merickel',
    author_email='oss@m.merickel.org',
    license='MIT',
    packages=find_packages('src', exclude=['tests']),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    python_requires='>=2.7,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*',
    extras_require={'testing': tests_require},
)
